@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
-   Copyright (C) 2003-2012 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2019 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,6 +31,8 @@
 #include "kexipartitem.h"
 #include "kexi.h"
 
+#include <KDbTableOrQuerySchema>
+
 /*! KexiProject implementation version.
  It is altered after every change:
  - major number is increased after KexiProject storage format change,
@@ -140,6 +142,19 @@ public:
      */
     QString pluginIdForTypeId(int typeId) const;
 
+    /**
+     * Returns table or query type for given plugin ID
+     *
+     * - KDbTableOrQuerySchema::Type::Table for "org.kexi-project.table"
+     * - KDbTableOrQuerySchema::Type::Query for "org.kexi-project.query"
+     *
+     * @a ok must not be @c nullptr. For "org.kexi-project.table" or "org.kexi-project.query" plugin
+     * ID *ok is set to @c true, for other IDs it is set to @c false and
+     * KDbTableOrQuerySchema::Type::Table is returned.
+     */
+    static KDbTableOrQuerySchema::Type pluginIdToTableOrQueryType(const QString &pluginId,
+                                                                  bool *ok);
+
     /**
      * @return all items of a type \a i in this project
      */
