@@ -105,7 +105,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const Command
 
 namespace KFormDesigner
 {
-class PropertyCommand::Private
+class Q_DECL_HIDDEN PropertyCommand::Private
 {
 public:
     Private()
@@ -308,7 +308,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const Property
 
 namespace KFormDesigner
 {
-class GeometryPropertyCommand::Private
+class Q_DECL_HIDDEN GeometryPropertyCommand::Private
 {
 public:
     Private()
@@ -409,7 +409,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const Geometry
 
 namespace KFormDesigner
 {
-class AlignWidgetsCommand::Private
+class Q_DECL_HIDDEN AlignWidgetsCommand::Private
 {
 public:
     Private()
@@ -575,7 +575,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const AlignWid
 
 namespace KFormDesigner
 {
-class AdjustSizeCommand::Private
+class Q_DECL_HIDDEN AdjustSizeCommand::Private
 {
 public:
     Private()
@@ -827,7 +827,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const AdjustSi
 
 namespace KFormDesigner
 {
-class InsertWidgetCommand::Private
+class Q_DECL_HIDDEN InsertWidgetCommand::Private
 {
 public:
     Private()
@@ -912,9 +912,13 @@ void InsertWidgetCommand::execute()
     if (!d->form->objectTree())
         return;
     ObjectTreeItem* titem = d->form->objectTree()->lookup(d->containerName);
-    if (!titem)
+    if (!titem) {
         return; //better this than a crash
+    }
     Container *container = titem->container();
+    if (!container) {
+        return;
+    }
     WidgetFactory::CreateWidgetOptions options = WidgetFactory::DesignViewMode | WidgetFactory::AnyOrientation;
     if (d->form->library()->internalProperty(d->_class, "orientationSelectionPopup").toBool()) {
         if (d->insertRect.isValid()) {
@@ -1062,7 +1066,7 @@ QByteArray InsertWidgetCommand::widgetName() const
 
 namespace KFormDesigner
 {
-class PasteWidgetCommand::Private
+class Q_DECL_HIDDEN PasteWidgetCommand::Private
 {
 public:
     Private()
@@ -1380,7 +1384,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const PasteWid
 
 namespace KFormDesigner
 {
-class DeleteWidgetCommand::Private
+class Q_DECL_HIDDEN DeleteWidgetCommand::Private
 {
 public:
     Private()
@@ -1475,7 +1479,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const DeleteWi
 
 namespace KFormDesigner
 {
-class DuplicateWidgetCommand::Private
+class Q_DECL_HIDDEN DuplicateWidgetCommand::Private
 {
 public:
     Private()
@@ -1547,7 +1551,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const Duplicat
 
 namespace KFormDesigner
 {
-class CutWidgetCommand::Private
+class Q_DECL_HIDDEN CutWidgetCommand::Private
 {
 public:
     Private()
@@ -1614,7 +1618,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const CutWidge
 
 namespace KFormDesigner
 {
-class PropertyCommandGroup::Private
+class Q_DECL_HIDDEN PropertyCommandGroup::Private
 {
 public:
     Private()
@@ -1658,7 +1662,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const Property
 
 namespace KFormDesigner
 {
-class InlineTextEditingCommand::Private
+class Q_DECL_HIDDEN InlineTextEditingCommand::Private
 {
 public:
     Private()
@@ -1780,7 +1784,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const InlineTe
 
 namespace KFormDesigner
 {
-class InsertPageCommand::Private
+class Q_DECL_HIDDEN InsertPageCommand::Private
 {
 public:
     Private()
@@ -1855,9 +1859,11 @@ void InsertPageCommand::execute(const QString& pageWidgetName, const QString& pa
         item->addModifiedProperty("title", realPageName);
     } else if (classname == "QStackedWidget" || /* compat */ classname == "QWidgetStack") {
         QStackedWidget *stack = qobject_cast<QStackedWidget*>(parent);
-        stack->addWidget(page);
-        stack->setCurrentWidget(page);
-        item->addModifiedProperty("stackIndex", stack->indexOf(page));
+        if (stack) {
+            stack->addWidget(page);
+            stack->setCurrentWidget(page);
+            item->addModifiedProperty("stackIndex", stack->indexOf(page));
+        }
     }
 }
 
@@ -1871,12 +1877,26 @@ void InsertPageCommand::undo(const QString& name)
     if (!name.isEmpty()) {
         d->name = name;
     }
-    QWidget *page = d->form->objectTree()->lookup(d->name)->widget();
-    QWidget *parent = d->form->objectTree()->lookup(d->parentname)->widget();
+    ObjectTreeItem *item = d->form->objectTree()->lookup(d->name);
+    if (!item) {
+        return;
+    }
+    QWidget *page = item->widget();
+    if (!page) {
+        return;
+    }
+    ObjectTreeItem *parentItem = d->form->objectTree()->lookup(d->parentname);
+    if (!parentItem) {
+        return;
+    }
+    QWidget *parent = parentItem->widget();
+    if (!parent) {
+        return;
+    }
 
     QWidgetList list;
     list.append(page);
-    Command *com = new DeleteWidgetCommand(*d->form, list);
+    DeleteWidgetCommand command(*d->form, list);
 
     QByteArray classname = parent->metaObject()->className();
     if (classname == "KFDTabWidget") {
@@ -1897,8 +1917,7 @@ void InsertPageCommand::undo(const QString& name)
         stack->removeWidget(page);
     }
 
-    com->execute();
-    delete com;
+    command.execute();
 }
 
 KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const InsertPageCommand &c)
@@ -1909,7 +1928,7 @@ KFORMDESIGNER_EXPORT QDebug KFormDesigner::operator<<(QDebug dbg, const InsertPa
 
 namespace KFormDesigner
 {
-class RemovePageCommand::Private
+class Q_DECL_HIDDEN RemovePageCommand::Private
 {
 public:
     Private()
@@ -1940,7 +1959,7 @@ RemovePageCommand::RemovePageCommand(Container *container, QWidget *parent)
     }
     d->parentname = parent->objectName();
     d->insertCommand = new InsertPageCommand(container, parent);
-    setText( kundo2_i18n("Remove Page") );
+    setText( kundo2_i18n("Delete Page") );
 }
 
 RemovePageCommand::~RemovePageCommand()
