@@ -82,7 +82,7 @@ void EventEater::setContainer(QObject *container)
 
 // Container itself
 
-class Container::Private
+class Q_DECL_HIDDEN Container::Private
 {
 public:
     Private(Container* toplevel_, QWidget *container)
@@ -1068,21 +1068,23 @@ Container::createGridLayout(bool testOnly)
         // " and will go to the col " << endcol;
 
         ObjectTreeItem *item = d->form->objectTree()->lookup(w->objectName());
-        if (!endrow && !endcol) {
-            if (!testOnly)
-                layout->addWidget(w, wrow, wcol);
-            item->setGridPos(wrow, wcol, 0, 0);
+        if (item) {
+            if (!endrow && !endcol) {
+                if (!testOnly)
+                    layout->addWidget(w, wrow, wcol);
+                item->setGridPos(wrow, wcol, 0, 0);
+            }
+            else {
+                if (!endcol)
+                    endcol = wcol;
+                if (!endrow)
+                    endrow = wrow;
+                if (!testOnly)
+                    layout->addWidget(w, wrow, wcol, endrow - wrow + 1, endcol - wcol + 1);
+                item->setGridPos(wrow, wcol, endrow - wrow + 1, endcol - wcol + 1);
+            }
         }
-        else {
-            if (!endcol)
-                endcol = wcol;
-            if (!endrow)
-                endrow = wrow;
-            if (!testOnly)
-                layout->addWidget(w, wrow, wcol, endrow - wrow + 1, endcol - wcol + 1);
-            item->setGridPos(wrow, wcol, endrow - wrow + 1, endcol - wcol + 1);
-        }
-    }
+    } //for
 }
 
 QString
@@ -1295,7 +1297,7 @@ void Container::setObjectTree(ObjectTreeItem *t)
 
 ////////////
 
-class DesignTimeDynamicChildWidgetHandler::Private
+class Q_DECL_HIDDEN DesignTimeDynamicChildWidgetHandler::Private
 {
 public:
     Private() : item(0) {}
