@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@gmx.at>
    Copyright (C) 2004 Cedric Pasteur <cedric.pasteur@free.fr>
-   Copyright (C) 2004-2014 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2017 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -193,12 +193,12 @@ int Form::defaultSpacing() const
     return 6;
 }
 
-QString Form::filename() const
+QString Form::fileName() const
 {
     return d->filename;
 }
 
-void Form::setFilename(const QString &file)
+void Form::setFileName(const QString &file)
 {
     d->filename = file;
 }
@@ -788,9 +788,7 @@ bool Form::addCommand(Command *command, AddCommandOption option)
     if (option == DontExecuteCommand) {
         command->blockRedoOnce();
     }
-    d->undoStack.push(command);
-    //qDebug() << "ADDED:" << *command;
-    return true;
+    return d->undoStack.push(command);
 }
 
 void Form::emitUndoEnabled()
@@ -943,22 +941,22 @@ void Form::autoAssignTabStops()
     }
 }
 
-int Form::formatVersion() const
+QString Form::formatVersion() const
 {
     return d->formatVersion;
 }
 
-void Form::setFormatVersion(int ver)
+void Form::setFormatVersion(const QString &ver)
 {
     d->formatVersion = ver;
 }
 
-int Form::originalFormatVersion() const
+QString Form::originalFormatVersion() const
 {
     return d->originalFormatVersion;
 }
 
-void Form::setOriginalFormatVersion(int ver)
+void Form::setOriginalFormatVersion(const QString &ver)
 {
     d->originalFormatVersion = ver;
 }
@@ -1240,7 +1238,7 @@ void Form::slotPropertyChanged(KPropertySet& set, KProperty& p)
             d->setColorProperty(p, &QWidget::backgroundRole, QVariant());
         }
     }
-    else if (property == "hAlign" || property == "vAlign" || property == "wordbreak") {
+    else if (property == "hAlign" || property == "vAlign") {
         saveAlignProperty(property);
         return;
     }
@@ -1589,7 +1587,8 @@ void Form::createPropertiesForWidget(QWidget *w)
                                        paletteForegroundColorDesc);
     d->propertySet.addProperty(newProp);
 
-    d->propertySet["objectName"].setAutoSync(false); // name should be updated only when pressing Enter
+    // name should be updated only when pressing Enter
+    d->propertySet["objectName"].setValueSyncPolicy(KProperty::ValueSyncPolicy::FocusOut);
 
     if (winfo) {
         library()->setPropertyOptions(d->propertySet, *winfo, w);
@@ -1651,7 +1650,6 @@ void Form::updatePropertiesForSelection(QWidget *w, WidgetSelectionFlags flags)
         flags |= ReplacePreviousSelection;
     }
 
-    QByteArray prevProperty;
     if (flags & ReplacePreviousSelection) {
         createPropertiesForWidget(w);
         w->installEventFilter(this);
@@ -2137,34 +2135,37 @@ void Form::createAlignProperty(const QMetaProperty& meta, QWidget *widget, QWidg
     if (!objectTree())
         return;
 
-    const int alignment = subwidget->property("alignment").toInt();
-    const QList<QByteArray> keys(meta.enumerator().valueToKeys(alignment).split('|'));
-    //qDebug() << "keys:" << keys;
-
-    const QStringList possibleValues(KexiUtils::enumKeysForProperty(meta));
-    //qDebug() << "possibleValues:" << possibleValues;
+    const Qt::Alignment alignment = Qt::Alignment(subwidget->property("alignment").toInt());
+    WidgetInfo *winfo = library()->widgetInfoForClassName(subwidget->metaObject()->className());
+    const Qt::Alignment supportedAlignmentFlags = winfo
+        ? winfo->supportedAlignmentFlags()
+        : Qt::Alignment(Qt::AlignHorizontal_Mask | Qt::AlignVertical_Mask);
     ObjectTreeItem *tree = objectTree()->lookup(widget->objectName());
     const bool isTopLevel = isTopLevelWidget(widget);
 
-    if (possibleValues.contains("AlignHCenter"))  {
+    const Qt::Alignment supportedHorizontalAlignmentFlags
+        = supportedAlignmentFlags & Qt::AlignHorizontal_Mask;
+    if (supportedHorizontalAlignmentFlags) {
         // Create the horizontal alignment property
-        QString value;
-        if (keys.contains("AlignHCenter") || keys.contains("AlignCenter"))
-            value = "AlignHCenter";
-        else if (keys.contains("AlignRight"))
-            value = "AlignRight";
-        else if (keys.contains("AlignLeft"))
-            value = "AlignLeft";
-        else if (keys.contains("AlignJustify"))
-            value = "AlignJustify";
-        else
-            value = "AlignAuto";
-
-        QStringList list;
-        list << "AlignAuto" << "AlignLeft" << "AlignRight"
-            << "AlignHCenter" << "AlignJustify";
+        QStringList list(KexiUtils::enumKeysForProperty(meta, supportedHorizontalAlignmentFlags));
+        if (list.removeOne(QStringLiteral("AlignHCenter"))) { // fix order
+            list.prepend(QStringLiteral("AlignHCenter"));
+        }
+        if (list.removeOne(QStringLiteral("AlignLeft"))) {
+            list.prepend(QStringLiteral("AlignLeft"));
+        }
+        const Qt::Alignment selectedHorizontalAlignmentFlags
+            = alignment & supportedHorizontalAlignmentFlags;
+        const QStringList selectedKeys(
+            KexiUtils::enumKeysForProperty(meta, selectedHorizontalAlignmentFlags));
+        QString selectedKey;
+        if (selectedKeys.isEmpty()) { // for sanity
+            selectedKey = list.first();
+        } else {
+            selectedKey = selectedKeys.first();
+        }
         KProperty *p = new KProperty(
-            "hAlign", d->createValueList(0, list), value,
+            "hAlign", d->createValueList(0, list), selectedKey,
             xi18nc("Translators: please keep this string short (less than 20 chars)", "Hor. Alignment"),
             xi18n("Horizontal Alignment"));
         d->propertySet.addProperty(p);
@@ -2174,20 +2175,28 @@ void Form::createAlignProperty(const QMetaProperty& meta, QWidget *widget, QWidg
         updatePropertyValue(tree, "hAlign");
     }
 
-    if (possibleValues.contains("AlignTop")) {
-        // Create the ver alignment property
-        QString value;
-        if (keys.contains("AlignTop"))
-            value = "AlignTop";
-        else if (keys.contains("AlignBottom"))
-            value = "AlignBottom";
-        else
-            value = "AlignVCenter";
-
-        QStringList list;
-        list << "AlignTop" << "AlignVCenter" << "AlignBottom";
+    const Qt::Alignment supportedVerticalAlignmentFlags
+        = supportedAlignmentFlags & Qt::AlignVertical_Mask;
+    if (supportedVerticalAlignmentFlags) {
+        QStringList list(KexiUtils::enumKeysForProperty(meta, supportedVerticalAlignmentFlags));
+        if (list.removeOne("AlignVCenter")) { // fix order
+            list.prepend("AlignVCenter");
+        }
+        if (list.removeOne("AlignTop")) {
+            list.prepend("AlignTop");
+        }
+        const Qt::Alignment selectedVerticalAlignmentFlags
+            = alignment & supportedVerticalAlignmentFlags;
+        const QStringList selectedKeys(
+            KexiUtils::enumKeysForProperty(meta, selectedVerticalAlignmentFlags));
+        QString selectedKey;
+        if (selectedKeys.isEmpty()) { // for sanity
+            selectedKey = list.first();
+        } else {
+            selectedKey = selectedKeys.first();
+        }
         KProperty *p = new KProperty(
-            "vAlign", d->createValueList(0, list), value,
+            "vAlign", d->createValueList(0, list), selectedKey,
             xi18nc("Translators: please keep this string short (less than 20 chars)", "Ver. Alignment"),
             xi18n("Vertical Alignment"));
         d->propertySet.addProperty(p);
@@ -2196,20 +2205,6 @@ void Form::createAlignProperty(const QMetaProperty& meta, QWidget *widget, QWidg
         }
         updatePropertyValue(tree, "vAlign");
     }
-
-    if (possibleValues.contains("WordBreak")) {
-        // Create the wordbreak property
-        KProperty *p = new KProperty("wordbreak",
-                QVariant((bool)(alignment & Qt::TextWordWrap)),
-                xi18n("Word Break"), xi18n("Word Break"));
-        d->propertySet.addProperty(p);
-        updatePropertyValue(tree, "wordbreak");
-        if (!library()->isPropertyVisible(
-                subwidget->metaObject()->className(), subwidget, p->name(), false/*multiple*/, isTopLevel))
-        {
-            p->setVisible(false);
-        }
-    }
 }
 
 void Form::saveAlignProperty(const QString &property)
@@ -2219,8 +2214,6 @@ void Form::saveAlignProperty(const QString &property)
         list.append(d->propertySet["hAlign"].value().toString());
     if (d->propertySet.contains("vAlign"))
         list.append(d->propertySet["vAlign"].value().toString());
-    if (d->propertySet.contains("wordbreak") && d->propertySet["wordbreak"].value().toBool())
-        list.append("WordBreak");
 
     WidgetWithSubpropertiesInterface* subpropIface
         = dynamic_cast<WidgetWithSubpropertiesInterface*>(d->selected.first());
@@ -2229,6 +2222,7 @@ void Form::saveAlignProperty(const QString &property)
     int count = subwidget->metaObject()->indexOfProperty("alignment");
     const QMetaProperty meta( subwidget->metaObject()->property(count) );
     const int valueForKeys = meta.enumerator().keysToValue(list.join("|").toLatin1());
+    const int oldValue = subwidget->property("alignment").toInt();
     subwidget->setProperty("alignment", valueForKeys);
 
     ObjectTreeItem *tree = objectTree()->lookup(d->selected.first()->objectName());
@@ -2241,15 +2235,10 @@ void Form::saveAlignProperty(const QString &property)
         return;
     }
 
-    if (d->lastCommand && d->lastCommand->propertyName() == "alignment") {
-        d->lastCommand->setValue(valueForKeys);
-    }
-    else {
-        d->lastCommand = new PropertyCommand(*this, d->selected.first()->objectName().toLatin1(),
-                                 subwidget->property("alignment"), valueForKeys, "alignment");
-        if (!addCommand(d->lastCommand, DontExecuteCommand)) {
-            d->lastCommand = 0;
-        }
+    d->lastCommand = new PropertyCommand(*this, d->selected.first()->objectName().toLatin1(),
+                                         oldValue, valueForKeys, "alignment");
+    if (!addCommand(d->lastCommand, DontExecuteCommand)) {
+        d->lastCommand = 0;
     }
 }
 
