@@ -51,6 +51,7 @@
 #include "utils.h"
 #include "widgetwithsubpropertiesinterface.h"
 #include "formIO.h"
+#include "KexiVersion.h"
 
 //! @todo KEXI3 TODO pixmapcollection
 #ifdef KEXI_PIXMAP_COLLECTIONS_SUPPORT
@@ -93,9 +94,9 @@ using namespace KFormDesigner;
 
 // FormIO itself
 
-KFORMDESIGNER_EXPORT int KFormDesigner::version()
+KFORMDESIGNER_EXPORT QString KFormDesigner::version()
 {
-    return KFORMDESIGNER_VERSION;
+    return QString::fromLatin1("%1.%2").arg(KEXI_STABLE_VERSION_MAJOR).arg(KEXI_STABLE_VERSION_MINOR);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -114,14 +115,14 @@ bool
 FormIO::saveFormToFile(Form *form, const QString &filename)
 {
     QString _filename;
-    if (!form->filename().isEmpty() && filename.isEmpty()) {
-        _filename = form->filename();
+    if (!form->fileName().isEmpty() && filename.isEmpty()) {
+        _filename = form->fileName();
     }
 
     if (filename.isEmpty()) {
         KexiFileDialog dlg(0, KexiFileDialog::SaveFile, "SaveForm");
         dlg.setNameFilter("*.ui|" + xi18n("Qt Designer UI Files"));
-        _filename = dlg.filename();
+        _filename = dlg.fileName();
         if (_filename.isEmpty()) {
             return false;
         }
@@ -129,7 +130,7 @@ FormIO::saveFormToFile(Form *form, const QString &filename)
     else {
         _filename = filename;
     }
-    form->setFilename(_filename);
+    form->setFileName(_filename);
 
     QDomDocument domDoc;
     if (!saveFormToDom(form, domDoc))
@@ -176,7 +177,7 @@ FormIO::saveFormToDom(Form *form, QDomDocument &domDoc)
     uiElement.setAttribute("stdsetdef", 1);
 
     //update format version information
-    form->headerProperties()->insert("version", QString::number(form->formatVersion()));
+    form->headerProperties()->insert("version", form->formatVersion());
     //custom properties
     QDomElement headerPropertiesEl = domDoc.createElement("kfd:customHeader");
     QHash<QByteArray, QString>::ConstIterator itEnd = form->headerProperties()->constEnd();
@@ -239,8 +240,8 @@ FormIO::loadFormFromByteArray(Form *form, QWidget *container, QByteArray &src, b
     int errLine;
     int errCol;
 
-    QDomDocument inBuf;
-    bool parsed = inBuf.setContent(src, false, &errMsg, &errLine, &errCol);
+    QDomDocument domDoc;
+    bool parsed = domDoc.setContent(src, false, &errMsg, &errLine, &errCol);
 
     if (!parsed) {
         qDebug() << errMsg;
@@ -248,7 +249,7 @@ FormIO::loadFormFromByteArray(Form *form, QWidget *container, QByteArray &src, b
         return false;
     }
 
-    if (!loadFormFromDom(form, container, inBuf)) {
+    if (!loadFormFromDom(form, container, domDoc)) {
         return false;
     }
     if (preview) {
@@ -258,18 +259,19 @@ FormIO::loadFormFromByteArray(Form *form, QWidget *container, QByteArray &src, b
 }
 
 bool
-FormIO::loadFormFromString(Form *form, QWidget *container, QString *src, bool preview)
+FormIO::loadFormFromString(Form *form, QWidget *container, const QString &src, bool preview)
 {
     QString errMsg;
     int errLine;
     int errCol;
 
 #ifdef KEXI_DEBUG_GUI
-    form->m_recentlyLoadedUICode = *src;
+    form->m_recentlyLoadedUICode = src;
 #endif
 
-    QDomDocument inBuf;
-    bool parsed = inBuf.setContent(*src, false, &errMsg, &errLine, &errCol);
+    QDomDocument domDoc;
+    //qDebug() << qPrintable(src);
+    bool parsed = domDoc.setContent(src, false, &errMsg, &errLine, &errCol);
 
     if (!parsed) {
         qWarning() << errMsg;
@@ -277,7 +279,7 @@ FormIO::loadFormFromString(Form *form, QWidget *container, QString *src, bool pr
         return false;
     }
 
-    if (!loadFormFromDom(form, container, inBuf)) {
+    if (!loadFormFromDom(form, container, domDoc)) {
         return false;
     }
     if (preview) {
@@ -297,7 +299,7 @@ FormIO::loadFormFromFile(Form *form, QWidget *container, const QString &filename
     if (filename.isEmpty()) {
         KexiFileDialog dlg(0, KexiFileDialog::OpenFile, "LoadForm");
         dlg.setNameFilter("*.ui|" + xi18n("Qt Designer UI Files"));
-        _filename = dlg.filename();
+        _filename = dlg.fileName();
         if (_filename.isEmpty()) {
             return false;
         }
@@ -324,40 +326,43 @@ FormIO::loadFormFromFile(Form *form, QWidget *container, const QString &filename
     return loadFormFromDom(form, container, doc);
 }
 
-bool
-FormIO::loadFormFromDom(Form *form, QWidget *container, QDomDocument &inBuf)
+bool FormIO::loadFormFromDom(Form *form, QWidget *container, const QDomDocument &domDoc)
 {
-    QDomElement ui = inBuf.firstChildElement("UI");
+    QDomElement ui = domDoc.firstChildElement("UI");
 
     //custom properties
     form->headerProperties()->clear();
     QDomElement headerPropertiesEl = ui.firstChildElement("kfd:customHeader");
     QDomAttr attr = headerPropertiesEl.firstChild().toAttr();
-    while (!attr.isNull() && attr.isAttr()) {
-        form->headerProperties()->insert(attr.name().toLatin1(), attr.value());
-        attr = attr.nextSibling().toAttr();
+    QDomNamedNodeMap attrs(headerPropertiesEl.attributes());
+    for(int i = 0; i < attrs.count(); ++i) {
+        const QDomAttr attr(attrs.item(i).toAttr());
+        if (!attr.isNull()) {
+            form->headerProperties()->insert(attr.name().toLatin1(), attr.value());
+        }
     }
     //update format version information
-    int ver = 1; //the default
-    if (form->headerProperties()->contains("version")) {
-        bool ok;
-        int v = (*form->headerProperties())["version"].toUInt(&ok);
-        if (ok)
-            ver = v;
-    }
-    //qDebug() << "original format version: " << ver;
+    QString ver = form->headerProperties()->value("version");
+    qDebug() << "Original format version: " << ver;
     form->setOriginalFormatVersion(ver);
-    if (ver < KFormDesigner::version()) {
-//! @todo We can either 1) convert from old format and later save in a new one or 2) keep old format.
-//!     To do this we may need to look at the original format version number.
-        qWarning() << "original format is older than current: " << KFormDesigner::version();
-        form->setFormatVersion(KFormDesigner::version());
-    } else
-        form->setFormatVersion(ver);
+    bool verOk;
+    const double verNum = ver.toDouble(&verOk);
+    const double currentVerNum = KFormDesigner::version().toDouble();
+    if (verOk) {
+        if (verNum < currentVerNum) {
+            //! @todo We can either 1) convert from old format and later save in a new one or 2) keep old format.
+            //!     To do this we may need to look at the original format version number.
+            qDebug() << "The original format version is:" << ver
+                     << "current version:" << KFormDesigner::version();
+            //return false;
+        }
+    }
+    form->setFormatVersion(ver);
 
-    if (ver > KFormDesigner::version()) {
+    if (verNum > currentVerNum) {
 //! @todo display information about too new format and that "some information will not be available".
-        qWarning() << "original format is newer than current: " << KFormDesigner::version();
+        qDebug() << "The original format is version" << ver
+                 << "is newer than current version:" << KFormDesigner::version();
     }
 
     // Load the pixmap collection
@@ -380,7 +385,7 @@ FormIO::loadFormFromDom(Form *form, QWidget *container, QDomDocument &inBuf)
             QString name = n.toElement().text();
             ObjectTreeItem *item = form->objectTree()->lookup(name);
             if (!item) {
-                qWarning() << "ERROR : no ObjectTreeItem ";
+                qWarning() << "Tabstops loading: no item" << name;
                 continue;
             }
             const int index = form->tabStops()->indexOf(item);
@@ -392,7 +397,7 @@ FormIO::loadFormFromDom(Form *form, QWidget *container, QDomDocument &inBuf)
             }
             if (index == -1) {
                 itemsNotFound++;
-                qDebug() << "FormIO: item '" << name << "' not in list";
+                qDebug() << "Tabstops loading: item" << name << "not on the list";
             }
         }
     }
