@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003-2017 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2018 Jarosław Staniek <staniek@kde.org>
 
    Contains code from kglobalsettings.cpp:
    Copyright (C) 2000, 2006 David Faure <faure@kde.org>
@@ -63,17 +63,16 @@
 #include <QProcess>
 
 #ifndef KEXI_MOBILE
-#include <kio_version.h>
+#include <KFileWidget>
+#include <KRecentDirs>
 #include <KRun>
 #include <KToolInvocation>
+#include <kio_version.h>
 #endif
 #include <KAboutData>
 #include <KColorScheme>
 #include <KConfigGroup>
-#include <KFileWidget>
 #include <KIconEffect>
-#include <KLocalizedString>
-#include <KRecentDirs>
 
 #if HAVE_LANGINFO_H
 #include <langinfo.h>
@@ -326,7 +325,9 @@ QUrl KexiUtils::getSaveImageUrl(QWidget *parent, const QString &caption, const Q
     }
 }
 
-QUrl KexiUtils::getStartUrl(const QUrl &startDirOrVariable, QString *recentDirClass)
+#ifndef KEXI_MOBILE
+QUrl KexiUtils::getStartUrl(const QUrl &startDirOrVariable, QString *recentDirClass,
+                            const QString &fileName)
 {
     QUrl result;
     if (recentDirClass) {
@@ -337,6 +338,9 @@ QUrl KexiUtils::getStartUrl(const QUrl &startDirOrVariable, QString *recentDirCl
         if (result.path().startsWith(protocol) && !result.path().startsWith(protocol + '/')) {
             result.setPath(result.path().mid(protocol.length() - 1));
         }
+        if (!fileName.isEmpty()) {
+            result.setPath(result.path() + '/' + fileName);
+        }
     } else {
         qWarning() << "Missing recentDirClass";
     }
@@ -347,6 +351,7 @@ void KexiUtils::addRecentDir(const QString &fileClass, const QString &directory)
 {
     KRecentDirs::add(fileClass, directory);
 }
+#endif
 
 bool KexiUtils::askForFileOverwriting(const QString& filePath, QWidget *parent)
 {
@@ -742,7 +747,12 @@ bool PaintBlocker::eventFilter(QObject* watched, QEvent* event)
 
 tristate KexiUtils::openHyperLink(const QUrl &url, QWidget *parent, const OpenHyperlinkOptions &options)
 {
-#ifndef KEXI_MOBILE
+#ifdef KEXI_MOBILE
+    //! @todo
+    Q_UNUSED(url)
+    Q_UNUSED(parent)
+    Q_UNUSED(options)
+#else
     if (url.isLocalFile()) {
         QFileInfo fileInfo(url.toLocalFile());
         if (!fileInfo.exists()) {
@@ -1015,7 +1025,6 @@ static QByteArray xfceSettingValue(const QByteArray &channel, const QByteArray &
     const QStringList arguments{ program, "-c", channel, "-p", property };
     QProcess process;
     process.start(programPath, arguments);//, QIODevice::ReadOnly | QIODevice::Text);
-    qDebug() << "a" << int(process.exitCode());
     if (!process.waitForStarted()) {
         qWarning() << "Count not execute command" << programPath << arguments
                    << "error:" << process.error();
@@ -1171,10 +1180,25 @@ QIcon themedIcon(const QString &name)
     return icon;
 }
 
-QString KexiUtils::localizedStringToHtmlSubstring(const KLocalizedString& string)
+QString KexiUtils::localizedStringToHtmlSubstring(const KLocalizedString &string)
 {
-    return string.toString(Kuit::RichText)
-            .remove(QLatin1String("<html>")).remove(QLatin1String("</html>"));
+    return string.isEmpty() ? QString()
+                            : string.toString(Kuit::RichText)
+                                  .remove(QLatin1String("<html>"))
+                                  .remove(QLatin1String("</html>"));
+}
+
+QString KexiUtils::localizedSentencesToHtml(const KLocalizedString &part1, const KLocalizedString &part2,
+                                    const KLocalizedString &part3, const KLocalizedString &part4,
+                                    const KLocalizedString &part5, const KLocalizedString &part6)
+{
+    return xi18nc("@info/plain Concatenated sentence1 sentence2 ...", "<html>%1%2%3%4%5%6</html>",
+                  KexiUtils::localizedStringToHtmlSubstring(part1),
+                  KexiUtils::localizedStringToHtmlSubstring(part2),
+                  KexiUtils::localizedStringToHtmlSubstring(part3),
+                  KexiUtils::localizedStringToHtmlSubstring(part4),
+                  KexiUtils::localizedStringToHtmlSubstring(part5),
+                  KexiUtils::localizedStringToHtmlSubstring(part6));
 }
 
 bool KexiUtils::cursorAtEnd(const QLineEdit *lineEdit)
