@@ -43,6 +43,7 @@
 #include <QUrl>
 
 #include <KIconLoader>
+#include <KLocalizedString>
 
 #include <KDbTristate>
 
@@ -51,7 +52,6 @@ class QDomNode;
 class QMetaProperty;
 class QLayout;
 class QLineEdit;
-class KLocalizedString;
 
 //! @short General Utils
 namespace KexiUtils
@@ -241,6 +241,7 @@ KEXIUTILS_EXPORT QUrl getOpenImageUrl(QWidget *parent = 0, const QString &captio
 KEXIUTILS_EXPORT QUrl getSaveImageUrl(QWidget *parent = 0, const QString &caption = QString(),
                                       const QUrl &directory = QUrl());
 
+#ifndef KEXI_MOBILE
 /**
  * This method implements the logic to determine the user's default directory
  * to be listed. E.g. the documents directory, home directory or a recently
@@ -249,13 +250,14 @@ KEXIUTILS_EXPORT QUrl getSaveImageUrl(QWidget *parent = 0, const QString &captio
  * Use instead of KFileWidget::getStartUrl(const QUrl &startDir, QString &recentDirClass).
  *
  * @param startDir A URL specifying the initial directory, or using the
- *                 @c kfiledialog:/// syntax to specify a last used
- *                 directory.  If this URL specifies a file name, it is
- *                 ignored.  Refer to the KFileWidget::KFileWidget()
- *                 documentation for the @c kfiledialog:/// URL syntax.
+ *                 @c kfiledialog:/// syntax to specify a last used directory.
+ *                 If the string includes a file name, it is ignored.
+ *                 Refer to the KFileWidget::KFileWidget() documentation for the @c kfiledialog:///
+ *                 URL syntax.
  * @param recentDirClass If the @c kfiledialog:/// syntax is used, this
  *        will return the string to be passed to KRecentDirs::dir() and
- *        KRecentDirs::add().
+ *        KRecentDirs::add(). Optional file name is supported.
+ * @param fileName Optional file name that is added to the resulting URL.
  * @return The URL that should be listed by default (e.g. by KFileDialog or
  *         KDirSelectDialog).
  *
@@ -263,7 +265,8 @@ KEXIUTILS_EXPORT QUrl getSaveImageUrl(QWidget *parent = 0, const QString &captio
  * @since 3.1.0
  * @todo Make it independent of KIOFileWidgets
  */
-KEXIUTILS_EXPORT QUrl getStartUrl(const QUrl &startDirOrVariable, QString *recentDirClass);
+KEXIUTILS_EXPORT QUrl getStartUrl(const QUrl &startDirOrVariable, QString *recentDirClass,
+                                  const QString &fileName = QString());
 
 /**
  * Associates @p directory with @p fileClass
@@ -274,6 +277,7 @@ KEXIUTILS_EXPORT QUrl getStartUrl(const QUrl &startDirOrVariable, QString *recen
  * @todo Make it independent of KIOFileWidgets
  */
 KEXIUTILS_EXPORT void addRecentDir(const QString &fileClass, const QString &directory);
+#endif // !KEXI_MOBILE
 
 /*! Displays a "The file %1 already exists. Do you want to overwrite it?" Yes/No message box.
  @a parent is used as a parent of the message box.
@@ -690,6 +694,18 @@ KEXIUTILS_EXPORT QString makeStandardCaption(const QString &userCaption,
  */
 KEXIUTILS_EXPORT QString localizedStringToHtmlSubstring(const KLocalizedString& string);
 
+/**
+ * Return rich text for concatenated sentences or paragraphs.
+ *
+ * Any of the parameters can be empty but at least first should be non-empty.
+ */
+KEXIUTILS_EXPORT QString localizedSentencesToHtml(
+    const KLocalizedString &part1, const KLocalizedString &part2 = KLocalizedString(),
+    const KLocalizedString &part3 = KLocalizedString(),
+    const KLocalizedString &part4 = KLocalizedString(),
+    const KLocalizedString &part5 = KLocalizedString(),
+    const KLocalizedString &part6 = KLocalizedString());
+
 /**
  * @return @c true if text cursor is at the end of the line edit @a lineEdit.
  * If the @a lineEdit edit has input mask, cursor is at the end if it's at position
