@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003-2013 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2018 Jarosław Staniek <staniek@kde.org>
    Copyright (C) 2012 Dimitrios T. Tanis <dimitrios.tanis@kdemail.net>
    Copyright (C) 2014 Roman Shtemberko <shtemberko@gmail.com>
 
@@ -35,7 +35,7 @@
 #include <kexiutils/KexiAssistantPage.h>
 #include <kexiutils/KexiLinkWidget.h>
 #include <widget/KexiConnectionSelectorWidget.h>
-#include <widget/KexiDBTitlePage.h>
+#include <widget/KexiDBCaptionPage.h>
 #include <widget/KexiProjectSelectorWidget.h>
 #include <KexiIcon.h>
 
@@ -48,6 +48,7 @@
 #include <KIconLoader>
 #include <KStandardGuiItem>
 
+#include <QAction>
 #include <QDebug>
 #include <QLayout>
 #include <QCheckBox>
@@ -77,7 +78,7 @@ KexiTemplateSelectionPage::KexiTemplateSelectionPage(QWidget* parent)
         parent)
 {
     m_templatesList = new KexiCategorizedView;
-    setFocusWidget(m_templatesList);
+    setRecentFocusWidget(m_templatesList);
     m_templatesList->setFrameShape(QFrame::NoFrame);
     m_templatesList->setContentsMargins(0, 0, 0, 0);
     int margin = style()->pixelMetric(QStyle::PM_MenuPanelWidth, 0, 0)
@@ -152,7 +153,6 @@ KexiProjectStorageTypeSelectionPage::KexiProjectStorageTypeSelectionPage(QWidget
  : KexiAssistantPage(xi18nc("@title:window", "Storage Method"),
                   xi18nc("@info", "Select a storage method which will be used to store the new project."),
                   parent)
- , m_fileTypeSelected(true)
 {
     setBackButtonVisible(true);
     QWidget* contents = new QWidget;
@@ -164,7 +164,7 @@ KexiProjectStorageTypeSelectionPage::KexiProjectStorageTypeSelectionPage(QWidget
     btn_server->setIcon(Kexi::serverIcon());
     btn_server->setIconSize(QSize(dsize, dsize));
     connect(btn_server, SIGNAL(clicked()), this, SLOT(buttonClicked()));
-    setFocusWidget(btn_file);
+    setRecentFocusWidget(btn_file);
 
     setContents(contents);
 }
@@ -175,10 +175,20 @@ KexiProjectStorageTypeSelectionPage::~KexiProjectStorageTypeSelectionPage()
 
 void KexiProjectStorageTypeSelectionPage::buttonClicked()
 {
-    m_fileTypeSelected = sender() == btn_file;
     next();
 }
 
+KexiProjectStorageTypeSelectionPage::Type KexiProjectStorageTypeSelectionPage::selectedType() const
+{
+    const QWidget *w = focusWidget();
+    if (w == btn_file) {
+        return Type::File;
+    } else if (w == btn_server) {
+        return Type::Server;
+    }
+    return Type::None;
+}
+
 // ----
 
 static QString defaultDatabaseName()
@@ -186,7 +196,7 @@ static QString defaultDatabaseName()
     return xi18n("New database");
 }
 
-KexiProjectTitleSelectionPage::KexiProjectTitleSelectionPage(QWidget* parent)
+KexiProjectCaptionSelectionPage::KexiProjectCaptionSelectionPage(QWidget* parent)
  : KexiAssistantPage(xi18nc("@title:window", "Project Caption & Filename"),
                   xi18nc("@info", "Enter caption for the new project. "
                        "Filename will be created automatically based on the caption. "
@@ -195,12 +205,12 @@ KexiProjectTitleSelectionPage::KexiProjectTitleSelectionPage(QWidget* parent)
 {
     setBackButtonVisible(true);
     setNextButtonVisible(true);
-    contents = new KexiDBTitlePage(QString());
+    contents = new KexiDBCaptionPage(QString());
     contents->formLayout->setSpacing(KexiUtils::spacingHint());
-    contents->le_title->setText(defaultDatabaseName());
-    contents->le_title->selectAll();
-    connect(contents->le_title, SIGNAL(textChanged(QString)),
-            this, SLOT(titleTextChanged(QString)));
+    contents->le_caption->setText(defaultDatabaseName());
+    contents->le_caption->selectAll();
+    connect(contents->le_caption, &KLineEdit::textChanged, this,
+            &KexiProjectCaptionSelectionPage::captionTextChanged);
     fileHandler = new KexiStartupFileHandler(
         QUrl("kfiledialog:///OpenExistingOrCreateNewProject"),
         KexiFileFilters::SavingFileBasedDB,
@@ -212,42 +222,43 @@ KexiProjectTitleSelectionPage::KexiProjectTitleSelectionPage(QWidget* parent)
     updateUrl();
 
     setContents(contents);
+    setRecentFocusWidget(contents->le_caption);
 }
 
-KexiProjectTitleSelectionPage::~KexiProjectTitleSelectionPage()
+KexiProjectCaptionSelectionPage::~KexiProjectCaptionSelectionPage()
 {
     delete fileHandler;
 }
 
-void KexiProjectTitleSelectionPage::askForOverwriting(const KexiContextMessage& message)
+void KexiProjectCaptionSelectionPage::askForOverwriting(const KexiContextMessage& message)
 {
     qDebug() << message.text();
     delete messageWidget;
     messageWidget = new KexiContextMessageWidget(this,
                                                  contents->formLayout,
                                                  contents->file_requester, message);
-    messageWidget->setNextFocusWidget(contents->le_title);
+    messageWidget->setNextFocusWidget(contents->le_caption);
 }
 
-void KexiProjectTitleSelectionPage::titleTextChanged(const QString & text)
+void KexiProjectCaptionSelectionPage::captionTextChanged(const QString &text)
 {
     Q_UNUSED(text);
     updateUrl();
 }
 
-void KexiProjectTitleSelectionPage::updateUrl()
+void KexiProjectCaptionSelectionPage::updateUrl()
 {
-    fileHandler->updateUrl(contents->le_title->text());
+    fileHandler->updateUrl(contents->le_caption->text());
 }
 
-bool KexiProjectTitleSelectionPage::isAcceptable()
+bool KexiProjectCaptionSelectionPage::isAcceptable()
 {
     delete messageWidget;
-    if (contents->le_title->text().trimmed().isEmpty()) {
+    if (contents->le_caption->text().trimmed().isEmpty()) {
         messageWidget = new KexiContextMessageWidget(contents->formLayout,
-                                                     contents->le_title,
+                                                     contents->le_caption,
                                                      xi18n("Enter project caption."));
-        contents->le_title->setText(QString());
+        contents->le_caption->setText(QString());
         return false;
     }
     QUrl url = contents->file_requester->url();
@@ -341,7 +352,7 @@ KexiProjectConnectionSelectionPage::KexiProjectConnectionSelectionPage(QWidget*
         connSelector->hideHelpers();
         connSelector->hideDescription();
         setContents(lyr);
-        setFocusWidget(connSelector->connectionsList());
+        setRecentFocusWidget(connSelector->connectionsList());
     }
     else {
         setDescription(QString());
@@ -382,16 +393,16 @@ KexiProjectDatabaseNameSelectionPage::KexiProjectDatabaseNameSelectionPage(
     m_le_dbname_txtchanged_enabled = true;
     contents = new KexiServerDBNamePage;
 
-    connect(contents->le_title, SIGNAL(textChanged(QString)),
-            this, SLOT(slotTitleChanged(QString)));
+    connect(contents->le_caption, &KLineEdit::textChanged, this,
+            &KexiProjectDatabaseNameSelectionPage::slotCaptionChanged);
     connect(contents->le_dbname, SIGNAL(textChanged(QString)),
             this, SLOT(slotNameChanged(QString)));
-    connect(contents->le_title, SIGNAL(returnPressed()),
-            this, SLOT(next()));
+    connect(contents->le_caption, &KLineEdit::returnPressed,
+            this, &KexiProjectDatabaseNameSelectionPage::next);
     connect(contents->le_dbname, SIGNAL(returnPressed()),
             this, SLOT(next()));
-    contents->le_title->setText(defaultDatabaseName());
-    contents->le_title->selectAll();
+    contents->le_caption->setText(defaultDatabaseName());
+    contents->le_caption->selectAll();
     KDbIdentifierValidator *idValidator = new KDbIdentifierValidator(this);
     idValidator->setLowerCaseForced(true);
     contents->le_dbname->setValidator(idValidator);
@@ -408,7 +419,7 @@ KexiProjectDatabaseNameSelectionPage::KexiProjectDatabaseNameSelectionPage(
     m_projectSelector->layout()->setContentsMargins(0, 0, 0, 0);
 
     setContents(contents);
-    setFocusWidget(contents->le_title);
+    setRecentFocusWidget(contents->le_caption);
 }
 
 KexiProjectDatabaseNameSelectionPage::~KexiProjectDatabaseNameSelectionPage()
@@ -439,7 +450,7 @@ bool KexiProjectDatabaseNameSelectionPage::setConnection(KDbConnectionData* data
     return true;
 }
 
-void KexiProjectDatabaseNameSelectionPage::slotTitleChanged(const QString &capt)
+void KexiProjectDatabaseNameSelectionPage::slotCaptionChanged(const QString &capt)
 {
     if (contents->le_dbname->text().isEmpty())
         m_dbNameAutofill = true;
@@ -468,11 +479,11 @@ QString KexiProjectDatabaseNameSelectionPage::enteredDbName() const
 bool KexiProjectDatabaseNameSelectionPage::isAcceptable()
 {
     delete messageWidget;
-    if (contents->le_title->text().trimmed().isEmpty()) {
+    if (contents->le_caption->text().trimmed().isEmpty()) {
         messageWidget = new KexiContextMessageWidget(contents->formLayout,
-                                                     contents->le_title,
+                                                     contents->le_caption,
                                                      xi18n("Enter project caption."));
-        contents->le_title->setText(QString());
+        contents->le_caption->setText(QString());
         return false;
     }
     QString dbName(enteredDbName());
@@ -506,7 +517,7 @@ bool KexiProjectDatabaseNameSelectionPage::isAcceptable()
                 this, contents->formLayout,
                 contents->le_dbname, message);
             messageWidget->setMessageType(KMessageWidget::Warning);
-            messageWidget->setNextFocusWidget(contents->le_title);
+            messageWidget->setNextFocusWidget(contents->le_caption);
             return false;
         }
     }
@@ -540,8 +551,8 @@ public:
     KexiProjectStorageTypeSelectionPage* projectStorageTypeSelectionPage() {
         return page<KexiProjectStorageTypeSelectionPage>(&m_projectStorageTypeSelectionPage);
     }
-    KexiProjectTitleSelectionPage* titleSelectionPage() {
-        return page<KexiProjectTitleSelectionPage>(&m_titleSelectionPage);
+    KexiProjectCaptionSelectionPage* captionSelectionPage() {
+        return page<KexiProjectCaptionSelectionPage>(&m_captionSelectionPage);
     }
     KexiProjectCreationPage* projectCreationPage() {
         return page<KexiProjectCreationPage>(&m_projectCreationPage);
@@ -567,7 +578,7 @@ public:
 
     QPointer<KexiTemplateSelectionPage> m_templateSelectionPage;
     QPointer<KexiProjectStorageTypeSelectionPage> m_projectStorageTypeSelectionPage;
-    QPointer<KexiProjectTitleSelectionPage> m_titleSelectionPage;
+    QPointer<KexiProjectCaptionSelectionPage> m_captionSelectionPage;
     QPointer<KexiProjectCreationPage> m_projectCreationPage;
     QPointer<KexiProjectConnectionSelectionPage> m_projectConnectionSelectionPage;
     QPointer<KexiProjectDatabaseNameSelectionPage> m_projectDatabaseNameSelectionPage;
@@ -585,6 +596,8 @@ KexiNewProjectAssistant::KexiNewProjectAssistant(QWidget* parent)
     setCurrentPage(d->templateSelectionPage());
     setFocusProxy(d->templateSelectionPage());
     setMessageHandler(this);
+    d->templateSelectionPage()->setFocusProxy(d->templateSelectionPage()->recentFocusWidget());
+    d->templateSelectionPage()->focusRecentFocusWidget();
 }
 
 KexiNewProjectAssistant::~KexiNewProjectAssistant()
@@ -598,22 +611,26 @@ void KexiNewProjectAssistant::nextPageRequested(KexiAssistantPage* page)
         setCurrentPage(d->projectStorageTypeSelectionPage());
     }
     else if (page == d->m_projectStorageTypeSelectionPage) {
-        if (d->projectStorageTypeSelectionPage()->fileTypeSelected()) {
-            setCurrentPage(d->titleSelectionPage());
-        }
-        else {
+        switch (d->projectStorageTypeSelectionPage()->selectedType()) {
+        case KexiProjectStorageTypeSelectionPage::Type::File:
+            setCurrentPage(d->captionSelectionPage());
+            break;
+        case KexiProjectStorageTypeSelectionPage::Type::Server:
             setCurrentPage(d->projectConnectionSelectionPage());
+            break;
+        default:
+            break;
         }
     }
-    else if (page == d->m_titleSelectionPage) {
-        if (!d->titleSelectionPage()->isAcceptable()) {
+    else if (page == d->m_captionSelectionPage) {
+        if (!d->captionSelectionPage()->isAcceptable()) {
             return;
         }
         //file-based project
         KDbConnectionData cdata;
         cdata.setDriverId(KDb::defaultFileBasedDriverId());
-        cdata.setDatabaseName(d->titleSelectionPage()->contents->file_requester->url().toLocalFile());
-        createProject(cdata, cdata.databaseName(), d->titleSelectionPage()->contents->le_title->text());
+        cdata.setDatabaseName(d->captionSelectionPage()->contents->file_requester->url().toLocalFile());
+        createProject(cdata, cdata.databaseName(), d->captionSelectionPage()->contents->le_caption->text());
     }
     else if (page == d->m_projectConnectionSelectionPage) {
         KDbConnectionData *cdata
@@ -646,7 +663,7 @@ void KexiNewProjectAssistant::nextPageRequested(KexiAssistantPage* page)
         //server-based project
         createProject(*d->m_projectDatabaseNameSelectionPage->conndataToShow,
                       d->m_projectDatabaseNameSelectionPage->contents->le_dbname->text().trimmed(),
-                      d->m_projectDatabaseNameSelectionPage->contents->le_title->text().trimmed());
+                      d->m_projectDatabaseNameSelectionPage->contents->le_caption->text().trimmed());
     }
 }
 
@@ -674,7 +691,7 @@ void KexiNewProjectAssistant::tryAgainActionTriggered()
 void KexiNewProjectAssistant::cancelActionTriggered()
 {
     if (currentPage() == d->m_passwordPage) {
-        d->passwordPage()->focusWidget()->setFocus();
+        d->passwordPage()->focusRecentFocusWidget();
     }
 }
 
