@@ -26,6 +26,7 @@
 #include <formeditor/commands.h>
 #include <formeditor/widgetwithsubpropertiesinterface.h>
 #include <formeditor/WidgetTreeWidget.h>
+#include <formeditor/WidgetInfo.h>
 #include <kexi.h>
 #include <kexi_global.h>
 #include <kexidragobjects.h>
@@ -235,15 +236,11 @@ bool KexiFormView::initForm()
     else {
         d->scrollView->setMainAreaWidget(d->dbform);
     }
-    d->dbform->setObjectName(
-        xi18nc("A prefix for identifiers of forms. Based on that, identifiers such as "
-            "form1, form2 are generated. "
-            "This string can be used to refer the widget object as variables in programming "
-            "languages or macros so it must _not_ contain white spaces and non latin1 characters, "
-            "should start with lower case letter and if there are subsequent words, these should "
-            "start with upper case letter. Example: smallCamelCase. "
-            "Moreover, try to make this prefix as short as possible.",
-            "form"));
+    const KFormDesigner::WidgetInfo *formInfo
+        = KexiFormManager::self()->library()->widgetInfoForClassName("KexiDBForm");
+    const QString formName
+        = formInfo ? formInfo->translatedNamePrefix() : QStringLiteral("form") /*sanity*/;
+    d->dbform->setObjectName(formName);
     QPalette pal(d->dbform->palette());
     pal.setBrush(QPalette::Window, palette().brush(QPalette::Window));
     d->dbform->setPalette(pal); // avoid inheriting QPalette::Window role
@@ -343,9 +340,13 @@ void KexiFormView::updateAutoFieldsDataSource()
     QString dataSourceString(d->dbform->dataSource());
     QString dataSourcePartClassString(d->dbform->dataSourcePluginId());
     KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
-    KDbTableOrQuerySchema tableOrQuery(
-        conn, dataSourceString.toLatin1(), dataSourcePartClassString == "org.kexi-project.table"
-        ? KDbTableOrQuerySchema::Type::Table :: KDbTableOrQuerySchema::Type::Query);
+    bool ok;
+    const KDbTableOrQuerySchema::Type type = KexiProject::pluginIdToTableOrQueryType(
+                dataSourcePartClassString, &ok);
+    if (!ok) {
+        return;
+    }
+    KDbTableOrQuerySchema tableOrQuery(conn, dataSourceString.toLatin1(), type);
     if (!tableOrQuery.table() && !tableOrQuery.query())
         return;
     foreach (KFormDesigner::ObjectTreeItem *item, *form()->objectTree()->hash()) {
@@ -370,10 +371,13 @@ void KexiFormView::updateValuesForSubproperties()
     QString dataSourceString(d->dbform->dataSource());
     QString dataSourcePartClassString(d->dbform->dataSourcePluginId());
     KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
-    KDbTableOrQuerySchema tableOrQuery(conn, dataSourceString.toLatin1(),
-                                       dataSourcePartClassString == "org.kexi-project.table"
-                                           ? KDbTableOrQuerySchema::Type::Table
-                                           : KDbTableOrQuerySchema::Type::Query);
+    bool ok;
+    const KDbTableOrQuerySchema::Type type = KexiProject::pluginIdToTableOrQueryType(
+                dataSourcePartClassString, &ok);
+    if (dataSourceString.isEmpty() || !ok) {
+        return;
+    }
+    KDbTableOrQuerySchema tableOrQuery(conn, dataSourceString.toLatin1(), type);
     if (!tableOrQuery.table() && !tableOrQuery.query())
         return;
 
@@ -629,8 +633,10 @@ void KexiFormView::initDataSource()
         sources = d->scrollView->usedDataSources();
         conn = KexiMainWindowIface::global()->project()->dbConnection();
         QString dataSourcePartClassString(d->dbform->dataSourcePluginId());
+        const KDbTableOrQuerySchema::Type type = KexiProject::pluginIdToTableOrQueryType(
+                    dataSourcePartClassString, &ok);
         if (dataSourcePartClassString.isEmpty() /*table type is the default*/
-            || dataSourcePartClassString == "org.kexi-project.table")
+            || type == KDbTableOrQuerySchema::Type::Table)
         {
             tableSchema = conn->tableSchema(dataSourceString);
             if (tableSchema) {
@@ -645,7 +651,7 @@ void KexiFormView::initDataSource()
 
         if (!tableSchema) {
             if (dataSourcePartClassString.isEmpty() /*also try to find a query (for compatibility with Kexi<=0.9)*/
-                || dataSourcePartClassString == "org.kexi-project.query")
+                || type == KDbTableOrQuerySchema::Type::Query)
             {
                 //try to find predefined query schema.
                 //Note: In general, we could not skip unused fields within this query because
@@ -1122,10 +1128,13 @@ KexiFormView::insertAutoFields(const QString& sourcePartClass, const QString& so
         return;
 
     KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
-    KDbTableOrQuerySchema tableOrQuery(conn, sourceName.toLatin1(),
-                                       sourcePartClass == "org.kexi-project.table"
-                                       ? KDbTableOrQuerySchema::Type::Table
-                                       : KDbTableOrQuerySchema::Type::Query);
+    bool ok;
+    const KDbTableOrQuerySchema::Type type = KexiProject::pluginIdToTableOrQueryType(
+                sourcePartClass, &ok);
+    if (sourceName.isEmpty() || !ok) {
+        return;
+    }
+    KDbTableOrQuerySchema tableOrQuery(conn, sourceName.toLatin1(), type);
     if (!tableOrQuery.table() && !tableOrQuery.query()) {
         qWarning() << "no such table/query" << sourceName;
         return;
