@@ -44,7 +44,7 @@
 #define KexiDBAutoField_SPACING 10 //10 pixel for spacing between a label and an editor widget
 
 //! @internal
-class KexiDBAutoField::Private
+class Q_DECL_HIDDEN KexiDBAutoField::Private
 {
 public:
     Private() {
@@ -63,6 +63,7 @@ public:
     QBrush textBrush; //!< needed because for unbound mode editor==0
     bool autoCaption;
     bool focusPolicyChanged;
+    KDbConnection *conn = nullptr;
 };
 
 //-------------------------------------
@@ -120,7 +121,7 @@ KexiDBAutoField::setWidgetType(WidgetType type)
     if (differ) {
         if (type == Auto) {// try to guess type from data source type
             if (visibleColumnInfo())
-                d->widgetType = KexiDBAutoField::widgetTypeForFieldType(visibleColumnInfo()->field->type());
+                d->widgetType = KexiDBAutoField::widgetTypeForFieldType(visibleColumnInfo()->field()->type());
             else
                 d->widgetType = Auto;
         } else
@@ -177,10 +178,14 @@ KexiDBAutoField::createEditor()
         newSubwidget->setObjectName(
             QString::fromLatin1("KexiDBAutoField_") + newSubwidget->metaObject()->className());
         KexiDataItemInterface *iface = dynamic_cast<KexiDataItemInterface*>(newSubwidget);
-        iface->setParentDataItemInterface(this);
+        if (iface) {
+            iface->setParentDataItemInterface(this);
+        }
         KexiFormDataItemInterface *formIface = dynamic_cast<KexiFormDataItemInterface*>(newSubwidget);
-        formIface->setColumnInfo(columnInfo()); //needed at least by KexiDBImageBox
-        formIface->setVisibleColumnInfo(visibleColumnInfo()); //needed at least by KexiDBComboBox
+        if (formIface) {
+            formIface->setColumnInfo(d->conn, columnInfo()); //needed at least by KexiDBImageBox
+            formIface->setVisibleColumnInfo(visibleColumnInfo()); //needed at least by KexiDBComboBox
+        }
         newSubwidget->setProperty("dataSource", dataSource()); //needed at least by KexiDBImageBox
         KFormDesigner::DesignTimeDynamicChildWidgetHandler::childWidgetAdded(this);
         newSubwidget->show();
@@ -480,21 +485,22 @@ KexiDBAutoField::setFieldCaptionInternal(const QString& text)
 }
 
 void
-KexiDBAutoField::setColumnInfo(KDbQueryColumnInfo* cinfo)
+KexiDBAutoField::setColumnInfo(KDbConnection *conn, KDbQueryColumnInfo* cinfo)
 {
-    KexiFormDataItemInterface::setColumnInfo(cinfo);
+    KexiFormDataItemInterface::setColumnInfo(conn, cinfo);
+    d->conn = conn;
     setColumnInfoInternal(cinfo, cinfo);
 }
 
-void
-KexiDBAutoField::setColumnInfoInternal(KDbQueryColumnInfo* cinfo, KDbQueryColumnInfo* visibleColumnInfo)
+void KexiDBAutoField::setColumnInfoInternal(KDbQueryColumnInfo *cinfo,
+                                            KDbQueryColumnInfo *visibleColumnInfo)
 {
     // change widget type depending on field type
     if (d->widgetType_property == Auto) {
         WidgetType newWidgetType = Auto;
         KDbField::Type fieldType;
         if (cinfo)
-            fieldType = visibleColumnInfo->field->type();
+            fieldType = visibleColumnInfo->field()->type();
         else if (dataSource().isEmpty())
             fieldType = KDbField::InvalidType;
         else
@@ -513,7 +519,7 @@ KexiDBAutoField::setColumnInfoInternal(KDbQueryColumnInfo* cinfo, KDbQueryColumn
 
     KexiFormDataItemInterface *iface = dynamic_cast<KexiFormDataItemInterface*>((QWidget*)subwidget());
     if (iface)
-        iface->setColumnInfo(visibleColumnInfo);
+        iface->setColumnInfo(d->conn, visibleColumnInfo);
 }
 
 //static
@@ -620,7 +626,7 @@ KexiDBAutoField::setDataSource(const QString &ds)
 {
     KexiFormDataItemInterface::setDataSource(ds);
     if (ds.isEmpty()) {
-        setColumnInfo(0);
+        setColumnInfo(d->conn, nullptr);
     }
 }
 
@@ -807,4 +813,3 @@ bool KexiDBAutoField::keyPressed(QKeyEvent *ke)
         return true;
     return false;
 }
-
