@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004-2012 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2017 Jarosław Staniek <staniek@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -95,13 +95,13 @@ public:
      If \a listData \a nlist if not NULL but empty, Property::setListData(0) is called. */
     virtual void changeFieldPropertyForRecord(int record,
                                            const QByteArray& propertyName, const QVariant& newValue,
-                                           KPropertyListData* const listData, bool addCommand);
+                                           const KPropertyListData* listData, bool addCommand);
 
     /*! Changes property \a propertyName to \a newValue.
      Works exactly like changeFieldPropertyForRecord(); except the field is pointed by \a fieldUID.
      Used by ChangeFieldPropertyCommand to change field's property. */
     void changeFieldProperty(int fieldUID, const QByteArray& propertyName,
-                             const QVariant& newValue, KPropertyListData* const listData = 0,
+                             const QVariant& newValue, const KPropertyListData* listData = nullptr,
                              bool addCommand = false);
 
     /*! Changes visibility of property \a propertyName to \a visible for a field pointed by \a fieldUID.
@@ -220,10 +220,6 @@ protected:
     void switchPrimaryKey(KPropertySet &propertySet, bool set, bool aWasPKey = false,
                           KexiTableDesignerCommands::Command* commandGroup = 0);
 
-    //! Gets subtype strings and names for type \a fieldType.
-    void getSubTypeListData(KDbField::TypeGroup fieldTypeGroup,
-                            QStringList& stringsList, QStringList& namesList);
-
     /*! Adds history command \a command to the undo/redo buffer.
      If \a execute is true, the command is executed afterwards. */
     void addHistoryCommand(KexiTableDesignerCommands::Command* command, bool execute);
