@@ -43,6 +43,7 @@
 #include <QEventLoop>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <QStandardPaths>
 #include <QUrl>
 
 //! @internal
@@ -121,6 +122,13 @@ void KexiStartupFileHandler::init(const QUrl &startDirOrVariable, KexiFileFilter
     else {
         url = startDirOrVariable;
     }
+    if (url.toLocalFile().isEmpty() || !QDir(url.toLocalFile()).exists()) {
+        url = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
+        QDir docDir(url.toLocalFile());
+        if (!docDir.exists()) { // create if missing
+            (void)docDir.mkpath(QString());
+        }
+    }
     d->setUrl(url);
     setMode(mode);
 /*removed in KEXI3
@@ -205,14 +213,17 @@ void KexiStartupFileHandler::updateFilters()
     QMimeType mime;
     QStringList allfilters;
 
-    const QString separator(KexiFileFilters::separator(KexiFileFilters::KDEFormat));
+    KexiFileFiltersFormat format;
+    format.type = KexiFileFiltersFormat::Type::KDE;
+    format.addAllFiles = true;
+    const QString separator(KexiFileFilters::separator(format));
     if (d->mode == KexiFileFilters::Opening || d->mode == KexiFileFilters::SavingFileBasedDB) {
         mime = db.mimeTypeForName(KDb::defaultFileBasedDriverMimeType());
         if (mime.isValid() && !d->excludedMimeTypes.contains(mime.name().toLower())) {
             if (!filter.isEmpty()) {
                 filter += separator;
             }
-            filter += KexiFileFilters::toString(mime, KexiFileFilters::KDEFormat);
+            filter += KexiFileFilters::toString(mime, format);
             allfilters += mime.globPatterns();
         }
     }
@@ -222,7 +233,7 @@ void KexiStartupFileHandler::updateFilters()
             if (!filter.isEmpty()) {
                 filter += separator;
             }
-            filter += KexiFileFilters::toString(mime, KexiFileFilters::KDEFormat);
+            filter += KexiFileFilters::toString(mime, format);
             allfilters += mime.globPatterns();
         }
     }
@@ -232,7 +243,7 @@ void KexiStartupFileHandler::updateFilters()
             if (!filter.isEmpty()) {
                 filter += separator;
             }
-            filter += KexiFileFilters::toString(mime, KexiFileFilters::KDEFormat);
+            filter += KexiFileFilters::toString(mime, format);
             allfilters += mime.globPatterns();
         }
     }
@@ -244,7 +255,7 @@ void KexiStartupFileHandler::updateFilters()
             if (!filter.isEmpty()) {
                 filter += separator;
             }
-            filter += KexiFileFilters::toString(mime, KexiFileFilters::KDEFormat);
+            filter += KexiFileFilters::toString(mime, format);
             allfilters += mime.globPatterns();
         }
     }
@@ -259,17 +270,11 @@ void KexiStartupFileHandler::updateFilters()
         if (!filter.isEmpty()) {
             filter += separator;
         }
-        filter += KexiFileFilters::toString(mimeName, KexiFileFilters::KDEFormat);
+        filter += KexiFileFilters::toString(mimeName, format);
         mime = db.mimeTypeForName(mimeName);
         allfilters += mime.globPatterns();
     }
 
-    if (!d->excludedMimeTypes.contains("all/allfiles")) {
-        if (!filter.isEmpty()) {
-            filter += separator;
-        }
-        filter += KexiFileFilters::toString("all/allfiles", KexiFileFilters::KDEFormat);
-    }
     //remove duplicates made because upper- and lower-case extenstions are used:
     QStringList allfiltersUnique = allfilters.toSet().toList();
     qSort(allfiltersUnique);
@@ -278,8 +283,8 @@ void KexiStartupFileHandler::updateFilters()
         if (!filter.isEmpty()) {
             filter += separator;
         }
-        filter.prepend(KexiFileFilters::toString(allfiltersUnique,
-            xi18n("All Supported Files"), KexiFileFilters::KDEFormat));
+        filter.prepend(
+            KexiFileFilters::toString(allfiltersUnique, xi18n("All Supported Files"), format));
     }
 
     d->requester->setFilter(filter);
@@ -453,12 +458,15 @@ void KexiStartupFileHandler::messageWidgetActionNoTriggered()
 void KexiStartupFileHandler::updateUrl(const QString &name)
 {
     QUrl url = d->requester->url();
+    QString path = url.toLocalFile();
+    if (!QFileInfo(path).isDir() && !path.endsWith('/')) {
+        url = url.adjusted(QUrl::RemoveFilename);
+        path = url.toLocalFile();
+    }
     QString fn = KDbUtils::stringToFileName(name);
     if (!fn.isEmpty() && !fn.endsWith(".kexi"))
         fn += ".kexi";
-    url = url.adjusted(QUrl::RemoveFilename);
-    qDebug() << url.toLocalFile();
-    url.setPath(url.toLocalFile() + fn);
+    url.setPath(QDir(path).absoluteFilePath(fn));
     d->requester->setUrl(url);
 }
 
