@@ -45,9 +45,9 @@ void KexiFormDataItemInterface::undoChanges()
 // m_disable_signalValueChanged = false;
 }
 
-KDbField* KexiFormDataItemInterface::field() const
+KDbField* KexiFormDataItemInterface::field()
 {
-    return m_columnInfo ? m_columnInfo->field : 0;
+    return m_columnInfo ? m_columnInfo->field() : nullptr;
 }
 
 void KexiFormDataItemInterface::setDisplayDefaultValue(QWidget* widget, bool displayDefaultValue)
