@@ -40,7 +40,7 @@
 #include <QDebug>
 
 //! @internal
-class KexiRelationsScrollArea::Private
+class Q_DECL_HIDDEN KexiRelationsScrollArea::Private
 {
 public:
     Private()
@@ -50,6 +50,7 @@ public:
         autoScrollTimer.setSingleShot(true);
     }
 
+    KDbConnection *connection = nullptr;
     QWidget *areaWidget;
     TablesHash tables;
     bool readOnly;
@@ -118,7 +119,7 @@ KexiRelationsScrollArea::KexiRelationsScrollArea(QWidget *parent)
 #if 0
     d->removeSelectedTableQueryAction = new QAction(xi18n("&Hide Selected Table/Query"), "edit-delete", "",
             this, SLOT(removeSelectedTableQuery()), parent->actionCollection(), "relationsview_removeSelectedTableQuery");
-    d->removeSelectedConnectionAction = new QAction(xi18n("&Remove Selected Relationship"), "dialog-cancel", "",
+    d->removeSelectedConnectionAction = new QAction(xi18n("&Delete Selected Relationship"), "dialog-cancel", "",
             this, SLOT(removeSelectedConnection()), parent->actionCollection(), "relationsview_removeSelectedConnection");
     d->openSelectedTableQueryAction = new QAction(xi18n("&Open Selected Table/Query"), "", "",
             this, SLOT(openSelectedTableQuery()), 0/*parent->actionCollection()*/, "relationsview_openSelectedTableQuery");
@@ -154,7 +155,7 @@ KexiRelationsScrollArea::tableContainer(KDbTableSchema *t) const
 KexiRelationsTableContainer*
 KexiRelationsScrollArea::addTableContainer(KDbTableSchema *t, const QRect &rect)
 {
-    if (!t)
+    if (!t || !d->connection)
         return 0;
 
     qDebug() << t->name();
@@ -165,10 +166,9 @@ KexiRelationsScrollArea::addTableContainer(KDbTableSchema *t, const QRect &rect)
         return c;
     }
 
-    c = new KexiRelationsTableContainer(d->areaWidget, this,
+    c = new KexiRelationsTableContainer(this, d->connection,
                                         /*! @todo what about query? */
-                                        new KDbTableOrQuerySchema(t)
-                                       );
+                                        new KDbTableOrQuerySchema(t), d->areaWidget);
     connect(c, SIGNAL(endDrag()), this, SLOT(slotTableViewEndDrag()));
     connect(c, SIGNAL(gotFocus()), this, SLOT(slotTableViewGotFocus()));
     connect(c, SIGNAL(contextMenuRequest(QPoint)),
@@ -276,7 +276,8 @@ KexiRelationsScrollArea::addConnection(const SourceConnection& _conn)
     /*! @todo will be moved up to relation/query part as this is only visual class
       KDbTableSchema *mtable = d->conn->tableSchema(conn.srcTable);
       KDbTableSchema *ftable = d->conn->tableSchema(conn.rcvTable);
-      KDbIndexSchema *forign = new KDbIndexSchema(ftable);
+      KDbIndexSchema *forign = new KDbIndexSchema;
+      ftable->addIndex(forign);
 
       forign->addField(mtable->field(conn.srcField));
       new KDbReference(forign, mtable->primaryKey());
@@ -497,6 +498,11 @@ KexiRelationsScrollArea::removeSelectedObject()
     }
 }
 
+void KexiRelationsScrollArea::setConnection(KDbConnection *conn)
+{
+    d->connection = conn;
+}
+
 void
 KexiRelationsScrollArea::hideTable(KexiRelationsTableContainer* container)
 {
