@@ -31,10 +31,11 @@
 #include <KDbTableViewData>
 #include <KDbTableViewColumn>
 #include <KDbTransaction>
+#include <KDbTransactionGuard>
 
 #include <QDebug>
 
-class KexiDataTableView::Private
+class Q_DECL_HIDDEN KexiDataTableView::Private
 {
 public:
     bool storeUserDataBlock(int objectID, const QString& dataID, const QString &dataString,
@@ -93,7 +94,7 @@ bool KexiDataTableView::loadTableViewSettings(KDbTableViewData* data)
             bool ok;
             const QList<int> columnWidths = KDb::deserializeIntList(columnWidthsString, &ok);
             if (!ok) {
-                qWarning() << "Invalud format of 'columnWidths' value:" << columnWidthsString;
+                qWarning() << "Invalid format of 'columnWidths' value:" << columnWidthsString;
                 return false;
             }
             QList<KDbTableViewColumn*>* columns = data->columns();
