@@ -73,6 +73,7 @@
 
 //#define KEXITABLEVIEW_DEBUG
 //#define KEXITABLEVIEW_DEBUG_PAINT
+//#define KEXITABLEVIEW_COMBO_DEBUG
 
 const int MINIMUM_ROW_HEIGHT = 17;
 
@@ -82,7 +83,7 @@ KexiTableScrollArea::Appearance::Appearance(QWidget *widget)
     if (qApp) {
         baseColor = KColorScheme(QPalette::Active, KColorScheme::View).background().color()/*QPalette::Base*/;
         textColor = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color()/*QPalette::Base*/;
-        QStyleOptionViewItemV4 option;
+        QStyleOptionViewItem option;
         option.initFrom(widget);
         const int gridHint = widget->style()->styleHint(QStyle::SH_Table_GridLineColor, &option, widget);
         gridColor = static_cast<QRgb>(gridHint);
@@ -131,7 +132,7 @@ void KexiTableViewCellToolTip::maybeTip( const QPoint & p )
     KDbRecordData *data = insertRowSelected ? m_tableView->m_insertItem : m_tableView->itemAt( row );
     if (editor && record && (col < (int)record->count())) {
       int w = m_tableView->columnWidth( col );
-      int h = m_tableView->rowHeight();
+      int h = m_tableView->recordHeight();
       int x = 0;
       int y_offset = 0;
       int align = SingleLine | AlignVCenter;
@@ -276,8 +277,18 @@ void KexiTableScrollArea::initDataContents()
 void KexiTableScrollArea::updateWidgetContentsSize()
 {
     updateScrollAreaWidgetSize();
-    d->horizontalHeader->setFixedSize(d->horizontalHeader->sizeHint());
-    d->verticalHeader->setFixedSize(d->verticalHeader->sizeHint());
+    if (d->horizontalHeader->sizeHint().width() > 0) {
+        d->horizontalHeader->setFixedWidth(d->horizontalHeader->sizeHint().width());
+    }
+    if (d->horizontalHeader->sizeHint().height() > 0) {
+        d->horizontalHeader->setFixedHeight(d->horizontalHeader->sizeHint().height());
+    }
+    if (d->verticalHeader->sizeHint().width() > 0) {
+        d->verticalHeader->setFixedWidth(d->verticalHeader->sizeHint().width());
+    }
+    if (d->verticalHeader->sizeHint().height() > 0) {
+        d->verticalHeader->setFixedHeight(d->verticalHeader->sizeHint().height());
+    }
     //qDebug() << d->horizontalHeader->sizeHint() << d->verticalHeader->sizeHint();
     //qDebug() << d->horizontalHeader->geometry() << d->verticalHeader->geometry();
 }
@@ -319,8 +330,8 @@ void KexiTableScrollArea::setFont(const QFont &font)
     if (d->recordHeight < MINIMUM_ROW_HEIGHT) {
         d->recordHeight = MINIMUM_ROW_HEIGHT;
     }
-    KexiDisplayUtils::initDisplayForAutonumberSign(d->autonumberSignDisplayParameters, this);
-    KexiDisplayUtils::initDisplayForDefaultValue(d->defaultValueDisplayParameters, this);
+    KexiDisplayUtils::initDisplayForAutonumberSign(&d->autonumberSignDisplayParameters, this);
+    KexiDisplayUtils::initDisplayForDefaultValue(&d->defaultValueDisplayParameters, this);
     update();
 }
 
@@ -338,6 +349,16 @@ void KexiTableScrollArea::updateAllVisibleRecordsBelow(int record)
                                 viewport()->height() - (recordPos(record) - verticalScrollBar()->value()));
 }
 
+void KexiTableScrollArea::setData(KDbTableViewData *data, bool owner)
+{
+    if (m_owner && m_data && m_data != data) {
+        // editors refer to KDbTableViewColumn objects that will be removed soon
+        qDeleteAll(d->editors);
+        d->editors.clear();
+    }
+    KexiDataAwareObjectInterface::setData(data, owner);
+}
+
 void KexiTableScrollArea::clearColumnsInternal(bool /*repaint*/)
 {
 }
@@ -350,14 +371,14 @@ void KexiTableScrollArea::slotUpdate()
     updateWidgetContentsSize();
 }
 
-Qt::SortOrder KexiTableScrollArea::currentLocalSortOrder() const
+KDbOrderByColumn::SortOrder KexiTableScrollArea::currentLocalSortOrder() const
 {
-    return d->horizontalHeader->sortIndicatorOrder();
+    return KDbOrderByColumn::fromQt(d->horizontalHeader->sortIndicatorOrder());
 }
 
-void KexiTableScrollArea::setLocalSortOrder(int column, Qt::SortOrder order)
+void KexiTableScrollArea::setLocalSortOrder(int column, KDbOrderByColumn::SortOrder order)
 {
-    d->horizontalHeader->setSortIndicator(column, order);
+    d->horizontalHeader->setSortIndicator(column, KDbOrderByColumn::toQt(order));
 }
 
 int KexiTableScrollArea::currentLocalSortColumn() const
@@ -514,7 +535,7 @@ void KexiTableScrollArea::drawContents(QPainter *p)
     if (rowfirst == -1 && (cy / d->recordHeight) == recordCount()) {
         // make the insert row paint too when requested
 #ifdef KEXITABLEVIEW_DEBUG
-        qDebug() << "rowfirst == -1 && (cy / d->rowHeight) == rowCount()";
+        qDebug() << "rowfirst == -1 && (cy / d->recordHeight) == recordCount()";
 #endif
         rowfirst = m_data->count();
         rowlast = rowfirst;
@@ -677,7 +698,7 @@ void KexiTableScrollArea::paintCell(QPainter* p, KDbRecordData *data, int record
         }
     }
 
-    const bool columnReadOnly = tvcol->isReadOnly();
+    const bool columnReadOnly = isReadOnly() || tvcol->isReadOnly();
     const bool dontPaintNonpersistentSelectionBecauseDifferentRowHasBeenHighlighted
         =    d->appearance.recordHighlightingEnabled && !d->appearance.persistentSelections
           && m_curRecord >= 0 && record != m_curRecord;
@@ -1270,7 +1291,7 @@ KexiDataItemInterface *KexiTableScrollArea::editor(int col, bool ignoreMissingEd
         return editor;
 
     //not found: create
-    editor = KexiCellEditorFactory::createEditor(*tvcol, d->scrollAreaWidget);
+    editor = KexiCellEditorFactory::createEditor(tvcol, d->scrollAreaWidget);
     if (!editor) {//create error!
         if (!ignoreMissingEditor) {
             //! @todo show error???
@@ -1280,7 +1301,7 @@ KexiDataItemInterface *KexiTableScrollArea::editor(int col, bool ignoreMissingEd
     }
     editor->hide();
     if (m_data->cursor() && m_data->cursor()->query())
-        editor->createInternalEditor(*m_data->cursor()->query());
+        editor->createInternalEditor(m_data->cursor()->connection(), *m_data->cursor()->query());
 
     connect(editor, SIGNAL(editRequested()), this, SLOT(slotEditRequested()));
     connect(editor, SIGNAL(cancelRequested()), this, SLOT(cancelEditor()));
@@ -1537,11 +1558,11 @@ void KexiTableScrollArea::updateCurrentCell()
 
 void KexiTableScrollArea::updateRecord(int record)
 {
-//    qDebug()<<record << horizontalScrollBar()->value() << recordPos(row) << viewport()->width() << rowHeight();
+//    qDebug()<<record << horizontalScrollBar()->value() << recordPos(row) << viewport()->width() << recordHeight();
     if (record < 0 || record >= (recordCount() + 2/* sometimes we want to refresh the row after last*/))
         return;
     //qDebug() << horizontalScrollBar()->value() << " " << verticalScrollBar()->value();
-    //qDebug() << QRect( columnPos( leftcol ), recordPos(row), viewport()->width(), rowHeight() );
+    //qDebug() << QRect( columnPos( leftcol ), recordPos(row), viewport()->width(), recordHeight() );
     d->scrollAreaWidget->update(horizontalScrollBar()->value(), recordPos(record),
                                 viewport()->width(), recordHeight());
 }
@@ -1673,19 +1694,17 @@ QRect KexiTableScrollArea::cellGeometry(int record, int column) const
                  columnWidth(column), recordHeight());
 }
 
-//#define KEXITABLEVIEW_COMBO_DEBUG
-
 QSize KexiTableScrollArea::tableSize() const
 {
 #ifdef KEXITABLEVIEW_COMBO_DEBUG
     if (objectName() == "KexiComboBoxPopup_tv") {
-        qDebug() << "rowCount" << rowCount() << "\nisInsertingEnabled" << isInsertingEnabled()
+        qDebug() << "rowCount" << recordCount() << "\nisInsertingEnabled" << isInsertingEnabled()
                  << "columnCount" << columnCount();
     }
 #endif
     if ((recordCount() + (isInsertingEnabled() ? 1 : 0)) > 0 && columnCount() > 0) {
         /*  qDebug() << columnPos( columnCount() - 1 ) + columnWidth( columnCount() - 1 )
-              << ", " << recordPos( rowCount()-1+(isInsertingEnabled()?1:0)) + d->rowHeight */
+              << ", " << recordPos( rowCount()-1+(isInsertingEnabled()?1:0)) + d->recordHeight */
 //  qDebug() << m_navPanel->isVisible() <<" "<<m_navPanel->height()<<" "
 //           << horizontalScrollBar()->sizeHint().height()<<" "<<recordPos( rowCount()-1+(isInsertingEnabled()?1:0));
         QSize s(
@@ -1698,8 +1717,9 @@ QSize KexiTableScrollArea::tableSize() const
             qDebug() << "size" << s
                      << "\ncolumnPos(columnCount()-1)" << columnPos(columnCount() - 1)
                      << "\ncolumnWidth(columnCount()-1)" << columnWidth(columnCount() - 1)
-                     << "\nrecordPos(rowCount()-1+(isInsertingEnabled()?1:0))" << recordPos(rowCount()-1+(isInsertingEnabled()?1:0))
-                     << "\nd->rowHeight" << d->rowHeight
+                     << "\nrecordPos(recordCount()-1+(isInsertingEnabled()?1:0))"
+                     << recordPos(recordCount()-1+(isInsertingEnabled()?1:0))
+                     << "\nd->recordHeight" << d->recordHeight
                      << "\nd->internal_bottomMargin" << d->internal_bottomMargin;
         }
 #endif
@@ -1851,7 +1871,7 @@ void KexiTableScrollArea::verticalScrollBarValueChanged(int v)
 void
 KexiTableScrollArea::print(QPrinter & /*printer*/ , QPrintDialog & /*printDialog*/)
 {
-    int leftMargin = printer.margins().width() + 2 + d->rowHeight;
+    int leftMargin = printer.margins().width() + 2 + d->recordHeight;
     int topMargin = printer.margins().height() + 2;
 // int bottomMargin = topMargin + ( printer.realPageSize()->height() * printer.resolution() + 36 ) / 72;
     int bottomMargin = 0;
@@ -1862,9 +1882,9 @@ KexiTableScrollArea::print(QPrinter & /*printer*/ , QPrintDialog & /*printDialog
     KDbRecordData *i;
     int width = leftMargin;
     for (int col = 0; col < columnCount(); col++) {
-        p.fillRect(width, topMargin - d->rowHeight, columnWidth(col), d->rowHeight, QBrush(Qt::gray));
-        p.drawRect(width, topMargin - d->rowHeight, columnWidth(col), d->rowHeight);
-        p.drawText(width, topMargin - d->rowHeight, columnWidth(col), d->rowHeight, Qt::AlignLeft | Qt::AlignVCenter,
+        p.fillRect(width, topMargin - d->recordHeight, columnWidth(col), d->recordHeight, QBrush(Qt::gray));
+        p.drawRect(width, topMargin - d->recordHeight, columnWidth(col), d->recordHeight);
+        p.drawText(width, topMargin - d->recordHeight, columnWidth(col), d->recordHeight, Qt::AlignLeft | Qt::AlignVCenter,
                    d->horizontalHeader->label(col));
         width = width + columnWidth(col);
     }
@@ -1880,14 +1900,14 @@ KexiTableScrollArea::print(QPrinter & /*printer*/ , QPrintDialog & /*printDialog
                 qDebug() << "col=" << col << "x=" << xOffset;
                 p.saveWorldMatrix();
                 p.translate(xOffset, yOffset);
-                paintCell(&p, i, row, col, QRect(0, 0, columnWidth(col) + 1, d->rowHeight), true);
+                paintCell(&p, i, row, col, QRect(0, 0, columnWidth(col) + 1, d->recordHeight), true);
                 p.restoreWorldMatrix();
                 xOffset = xOffset + columnWidth(col);
                 right = xOffset;
             }
 
             row++;
-            yOffset = topMargin  + row * d->rowHeight;
+            yOffset = topMargin  + row * d->recordHeight;
         }
 
         if (yOffset > 900) {
@@ -2058,7 +2078,7 @@ void KexiTableScrollArea::updateViewportMargins()
         0 // bottom
     );
     setViewportMargins(d->viewportMargins);
-    qDebug() << d->viewportMargins;
+    //qDebug() << d->viewportMargins;
 }
 
 bool KexiTableScrollArea::horizontalHeaderVisible() const
