@@ -97,7 +97,7 @@ public:
 // ----
 
 //! @internal
-class KexiRecordNavigator::Private
+class Q_DECL_HIDDEN KexiRecordNavigator::Private
 {
 public:
     Private(KexiRecordNavigator *navigator)
